import json  # noqa: F401
import unittest

from datetime import date, datetime

from switcore.action.schemas import UserActionType, \
    QueryResource, TaskResource, TaskStatus, TaskUser, TaskStatusType
from tests.utils import create_submit_swit_request, create_query_swit_request, create_task_swit_request


class SwitViewResponseTest(unittest.TestCase):

    def test_swit_submit_request(self):
        swit_request: SwitRequest = create_submit_swit_request("right_panel", "test_action_id01")
        self.assertEqual(swit_request.user_action.type, UserActionType.view_actions_submit)

    def test_swit_query_request(self):
        swit_request: SwitRequest = create_query_swit_request()
        self.assertEqual(swit_request.user_action.type, UserActionType.view_actions_query)
        self.assertTrue(isinstance(swit_request.user_action.resource, QueryResource))

    def test_swit_task_request(self):
        swit_request: SwitRequest = create_task_swit_request()
        self.assertEqual(swit_request.user_action.type, UserActionType.user_commands_context_menus_task.value)
        self.assertTrue(isinstance(swit_request.user_action.resource, TaskResource))
        assert isinstance(swit_request.user_action.resource, TaskResource)
        self.assertEqual(swit_request.user_action.resource.id, "23051106260551ZOVCPS")
        self.assertEqual(swit_request.user_action.resource.parent_task_id, "200302045745598izpK")
        self.assertEqual(swit_request.user_action.resource.title, "Developers documentation")
        self.assertEqual(swit_request.user_action.resource.status, TaskStatus(
            id="220707214090V110qhk",
            name="Done",
            type=TaskStatusType.NOT_STARTED
        ))
        self.assertEqual(swit_request.user_action.resource.assignees, [TaskUser(id="220103011810x7bqTRZ")])
        self.assertEqual(swit_request.user_action.resource.color_label, None)

        # Test with pure date types
        swit_request2 = create_task_swit_request({
            "start_time": "",
            "due_time": "2023-02-14",
            "include_time": False
        })
        due_time = swit_request2.user_action.resource.period.due_time
        self.assertTrue(isinstance(due_time, date))
        self.assertFalse(isinstance(due_time, datetime))



from datetime import datetime

from sqlalchemy import Column, String, Integer, DateTime, func
from sqlalchemy.ext.declarative import declarative_base
from sqlalchemy.orm import Mapped

base_model = declarative_base()


class BaseModel(base_model):
    __abstract__ = True

    id: Mapped[int] = Column(Integer, primary_key=True, index=True, autoincrement=True)
    created: Mapped[datetime] = Column(DateTime, default=func.now())
    updated: Mapped[datetime] = Column(DateTime, default=func.now(), onupdate=func.now())


class App(BaseModel):
    __tablename__ = 'app'

    access_token: Mapped[str] = Column(String(500), nullable=False)
    refresh_token: Mapped[str] = Column(String(50), nullable=False)
    iss: Mapped[str] = Column(String(50), nullable=False)
    cmp_id: Mapped[str] = Column(String(50), nullable=False)
    apps_id: Mapped[str] = Column(String(50), nullable=False)


class User(BaseModel):
    __tablename__ = 'user'

    swit_id: Mapped[str] = Column(String(100), nullable=False, index=True)
    access_token: Mapped[str | None] = Column(String(500), nullable=True)
    refresh_token: Mapped[str | None] = Column(String(50), nullable=True)



import json
import os
import importlib.util

def load_classes_from_directory(directory):
    classes = []  # 로드된 클래스를 저장할 리스트

    for filename in os.listdir(directory):
        if filename.endswith('.py') and not filename.startswith('__'):
            module_name = filename[:-3]  # 확장자 제거
            module_path = os.path.join(directory, filename)

            spec = importlib.util.spec_from_file_location(module_name, module_path)
            module = importlib.util.module_from_spec(spec)
            spec.loader.exec_module(module)

            for attribute_name in dir(module):
                attribute = getattr(module, attribute_name)
                if isinstance(attribute, type):  # 클래스인지 확인
                    classes.append(attribute)

    return classes

# 사용 예시
directory_path = 'switcore/ui'  # 디렉토리 경로 설정
loaded_classes = load_classes_from_directory(directory_path)

# 로드된 클래스 출력
for cls in loaded_classes:
    if hasattr(cls, 'model_json_schema'):
        method = getattr(cls, 'model_json_schema')
        print("######################start########################")
        print(cls)
        result = method()
        print(json.dumps(result, indent=2))
        print("######################end########################")
    # print(cls)
